

set -ex



clang-12 --version
test ! -f "$PREFIX/bin/clang"
test ! -f "$PREFIX/bin/clang-cl"
test ! -f "$PREFIX/bin/clang-cpp"
test ! -f "$PREFIX/lib/libclang-cpp.dylib"
test -f "$PREFIX/lib/libclang-cpp.12.dylib"
test -f "$PREFIX/lib/clang/12.0.0/include/stdatomic.h"
exit 0
